; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| AI Activation Commands |-----------------------------------------------
; From BBH
[Command]
name = "CPU0"
command = D,D,D,D,B,F,B,F,s,s
time = 0

[Command]
name = "CPU1"
command = F,U,F,D,B,F,B,F,c,a
time = 0

[Command]
name = "CPU2"
command = F,F,D,D,B,F,B,F,b,b
time = 0

[Command]
name = "CPU3"
command = U,D,D,D,B,F,B,F,F,c
time = 0

[Command]
name = "CPU4"
command = D,U,D,D,B,F,B,F,x,x
time = 0

[Command]
name = "CPU5"
command = U,D,D,D,B,F,B,F,F,y
time = 0

[Command]
name = "CPU6"
command = F,U,D,D,B,F,B,F,z,z
time = 0

[Command]
name = "CPU7"
command = F,U,D,D,B,F,B,F,a,b
time = 0

[Command]
name = "CPU8"
command = U,U,D,D,B,F,F,F,b,c
time = 0


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "SuperButSlam!"
command = ~B, DB, D, DF, F, x+y
time = 15

[Command]
name = "BrownAlbert"
command = ~D, DF, F, a+b

[Command]
name = "Avalanche"
command = ~F, DF, D, DB, B, a+b
time = 35

[Command]
name = "PeptoPunch"
command = ~D, DB, B, z

[Command]
name = "Spinx"
command = ~D, DB, B, y+z

[Command]
name = "Chabacker2"
command = ~D, D, a+b
time = 15

[Command]
name = "crusher"
command = ~D, D , y+z

[Command]
name = "boom"
command = x+y


[Command]
name = "Pop-Pa"
command = ~D, DF, F, a+b
time = 45

[Command]
name = "SuperBuble!"
command = ~B, DB, D, DF, F, y+z
time = 15

[Command]
name = "dragon5"
command = ~F, DF,D ,DB ,B, x+y
time = 45

[Command]
name = "Superjunksion"
command = ~D, D , y+z
time = 45


[Command]
name = "easysupyz"
command = y+z
time = 15

[Command]
name = "easysupxy"
command = x+y
time = 15

[Command]
name = "easysupbc"
command = b+c
time = 15

[Command]
name = "easysupab"
command = a+b
time = 15

;-| Special Motions |------------------------------------------------------


[Command]
name = "easyz";Required (do not remove)
command = ~z,z
time = 15

[Command]
name = "easyx";Required (do not remove)
command = ~x,x
time = 15

[Command]
name = "easyy";Required (do not remove)
command = ~y,y
time = 15

[Command]
name = "easya";Required (do not remove)
command = ~a,a
time = 15

[Command]
name = "easyb";Required (do not remove)
command = ~b,b
time = 15

[Command]
name = "easyc";Required (do not remove)
command = ~c,c
time = 15

[Command]
name = "Mud"
command = a+b

[Command]
name = "Phatsolo"
command = ~D, DF, F, c

[Command]
name = "ButSlam"
command = /D , b
time = 45

[Command]
name = "ButSlam"
command = /DB , b
time = 45

[Command]
name = "ButSlam"
command = /DF , b
time = 45

[Command]
name = "Gum"
command = ~D, DF, F, b

[Command]
name = "Fart"
command = ~D, DF, F, z

[Command]
name = "Array"
command = ~D, DF, F, y

[Command]
name = "Powerfly"
command = a+b

[Command]
name = "BRANG"
command = ~D ,DB ,B, a

[Command]
name = "yardslam"
command = ~F, DF, D, DB, B, y

[Command]
name = "razzle"
command = ~F, D, DF, a

[Command]
name = "DivePunchc"
command = ~F, D, DF, F, c

[Command]
name = "dragon1"
command = ~D, DB, B, x

[Command]
name = "dragon2"
command = ~B, DB, D, DF, F, y
time = 45

[Command]
name = "dragon3"
command = ~D, DF, F, x

[Command]
name = "Donald"
command = ~F ,D, DF, z
time = 15

[Command]
name = "Junksion"
command = ~D, DB, B, b
time = 15

[Command]
name = "russel"
command = ~D, DF, F, b
time = 15

[Command]
name = "Bucky"
command = ~D, DF, F, y
time = 15

[Command]
name = "Slash"
command = ~D, DB, B, c
time = 20

[Command]
name = "Slash2"
command = ~D, DB, B, a
time = 20

[Command]
name = "Slash3"
command = ~D, DB, B, b
time = 20

[Command]
name = "Assist"
command = ~D, DF, F, a 
time = 15

[Command]
name = "Assist2"
command = ~D, DF, F, y 
time = 15

[Command]
name = "Assist3"
command = ~D, D, z 
time = 15

[Command]
name = "Fired-Up!"
command =  b+c 
time = 45

[Command]
name = "Assist4"
command = ~D, DB, B, y 
time = 15

[Command]
name = "Assist5"
command = ~D, DB, B, z 
time = 15

[Command]
name = "Assist6"
command = ~F, D, DF, y 
time = 15

[Command]
name = "Phant"
command = ~D, DB, B, y
time = 15

[Command]
name = "Phant2"
command = ~D, DB, B, z
time = 15

[Command]
name = "Powerfly"
command = ~D, DF, F, z
time = 15

[Command]
name = "SuperJumpUp"
command = D, U

[Command]
name = "SuperJumpFwd"
command = D, UF

[Command]
name = "SuperJumpBck"
command = D, UB

[Command]
name = "UFRun"     
command = /UF, y+z

[Command]
name = "UBRun"     
command = /UB, y+z

[Command]
name = "DFRun"     
command = /DF, y+z


[Command]
name = "DBRun"     
command = /DB, y+z

[Command]
name = "FRun"     
command = /F, y+z

[Command]
name = "BRun"     
command = /B, y+z 


[Command]
name = "URun"     
command = /U, y+z

[Command]
name = "DRun"     
command = /D, y+z

[Command]
name = "HoldB"
command = /b

[Command]
name = "HoldC"
command = /c

[Command]
name = "HoldA"
command = /a

[Command]
name = "HoldZ"
command = /z

[Command]
name = "HoldX"
command = /x

[Command]
name = "HoldY"
command = /y

[Command]
name = "HoldZ"
command = /z

[Command]
name = "HoldKICKS"
command = /a+b 

[Command]
name = "Up"
command = U

[Command]
name = "Down"
command = D



;-| Dir + Button |---------------------------------------------------------

[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_x"
command = /B,x
time = 1

[Command]
name = "back_y"
command = /B,y
time = 1

[Command]
name = "back_z"
command = /B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

[Command]
name = "airlaucher"
command = /DF, z
time = 1

[Command]
name = "Raw"
command = ~U, U, U, D, D
time = 65


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 5

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;AI Activation
[State -1]
type = VarSet
triggerall = roundstate = 1
trigger1 = command = "CPU0"
trigger2 = command = "CPU1"
trigger3 = command = "CPU2"
trigger4 = command = "CPU3"
trigger5 = command = "CPU4"
trigger6 = command = "CPU5"
trigger7 = command = "CPU6"
trigger8 = command = "CPU7"
v = 13
value = 1

;AI Activation
[State -1]
type = VarSet
trigger1 = roundstate = 1
trigger2 = roundstate = 3
trigger3 = roundstate = 4
v = 13
value = 0

;AI Activation
[State -1]
type = VarSet
;triggerall = roundstate = 2
trigger1 = numhelper(9980) = 1;command = "CPU0"
v = 59
value = 1

;AI Activation
[State -1]
type = VarSet
;triggerall = roundstate = 2
trigger1 = numhelper(9981) = 1;command = "CPU0"
v = 59
value = 0


;AI Comming Soon
;------------------------------------

;AI Push Block (Thanks to BB Hood!)
[State -1]
type = ChangeState
value = 860
triggerall = var(13) = 1
triggerall = random < 50
trigger1 = stateno = [150,151]

[State -1]
type = ChangeState
value = 870
triggerall = var(13) = 1
triggerall = random < 50
trigger1 = stateno = [152,153]

[State -1]
type = ChangeState
value = 880
triggerall = var(13) = 1
triggerall = random < 50
trigger1 = stateno = 154
trigger2 = stateno = 155
trigger2 = Time <= 10

;===========================================================================
; Put specials and supers here

[State 8017]
type = null;Helper
triggerall = numhelper(3033) = 0
trigger1 = Gametime <= 10
trigger1 = command = "a"
id = 3033
helpertype = normal
postype = p1
pos = -90,-300
stateno = 4213;4211
keyctrl = 1
ownpal = 1
;supermovetime = 9999
size.xscale = .99
size.yscale = .97

; Assist Bluto
[State -1, ]
type = ChangeState
value = 4210
triggerall = statetype = S || Statetype = C || Statetype = A
triggerall = Command = "Avalanche"
trigger1 = ctrl

; Assist Bluto
[State -1, ]
type = ChangeState
value = 4216
triggerall = numhelper(3033) = 1
triggerall = statetype = S || Statetype = C || Statetype = A
triggerall = Command = "Fired-Up!"
trigger1 = ctrl

; Assist Bluto
[State -1, ]
type = ChangeState
value = 1327
triggerall = NumHelper(5001) = 1
triggerall = statetype = S || Statetype = C || Statetype = A
triggerall = Command = "SuperButSlam!"
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
trigger12 = MoveContact
trigger13 = stateno = 420
trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = stateno = 4278
trigger24 = stateno = 2445
trigger25 = stateno = 1310
trigger26 = stateno = 1331
trigger27 = stateno = 1330
trigger28 = stateno = 1380
trigger29 = stateno = 3031
trigger30 = stateno = 4036
trigger31 = stateno = 1325;11
trigger32 = stateno = 1270
trigger33 = stateno = 4103
trigger34 = stateno = 4104
trigger35 = stateno = 4105
trigger36 = stateno = 4106
trigger37 = stateno = 4107
trigger38 = stateno = 4108
trigger39 = stateno = 4109
trigger40 = stateno = 4110
trigger41 = stateno = 4065
trigger42 = stateno = 4102
trigger43 = stateno = 1390
trigger44 = stateno = 2455
trigger45 = stateno = 1315

; Assist Bluto
[State -1, ]
type = ChangeState
value = 1327
triggerall = NumHelper(5001) = 1
triggerall = statetype = S || Statetype = C || Statetype = A
triggerall = command = "easysupxy";"Bucky"
triggerall = command = "holddown"
triggerall = Var(59) = 1
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
trigger12 = MoveContact
trigger13 = stateno = 420
trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = stateno = 4278
trigger24 = stateno = 2445
trigger25 = stateno = 1310
trigger26 = stateno = 1331
trigger27 = stateno = 1330
trigger28 = stateno = 1380
trigger29 = stateno = 3031
trigger30 = stateno = 4036
trigger31 = stateno = 1325;11
trigger32 = stateno = 1270
trigger33 = stateno = 4103
trigger34 = stateno = 4104
trigger35 = stateno = 4105
trigger36 = stateno = 4106
trigger37 = stateno = 4107
trigger38 = stateno = 4108
trigger39 = stateno = 4109
trigger40 = stateno = 4110
trigger41 = stateno = 4065
trigger42 = stateno = 4102
trigger43 = stateno = 1390
trigger44 = stateno = 2455
trigger45 = stateno = 1315


;------------------------------------------

; Assist Bluto
[State -1, ]
type = ChangeState
value = 1341
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = statetype = S || Statetype = C
triggerall = Command = "dragon5"
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
trigger12 = MoveContact
trigger13 = stateno = 420
trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = stateno = 1311
trigger18 = stateno = 1300
trigger19 = stateno = 1380
trigger20 = stateno = 4291
trigger21 = stateno = 4290
trigger22 = stateno = 1392

; Assist Bluto
[State -1, ]
type = ChangeState
value = 1341
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = statetype = S || Statetype = C
triggerall = command = "easysupxy";"Bucky"
triggerall = command = "holdback"
triggerall = Var(59) = 1
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
trigger12 = MoveContact
trigger13 = stateno = 420
trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = stateno = 1311
trigger18 = stateno = 1300
trigger19 = stateno = 1380
trigger20 = stateno = 4291
trigger21 = stateno = 4290
trigger22 = stateno = 1392

;----------------------------------------------------------------------------
; Dragon Punch (medium)
[State -1, ]
type = ChangeState
value = 4102
triggerall = command = "boom"
triggerall = numhelper(4094) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 210
trigger3 = MoveContact
trigger4 = stateno = 220
trigger4 = MoveContact
trigger5 = stateno = 230
trigger5 = MoveContact
trigger6 = stateno = 240
trigger6 = MoveContact
trigger7 = stateno = 250
trigger7 = MoveContact
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 600
trigger14 = MoveContact
trigger15 = stateno = 610
trigger15 = MoveContact
trigger16 = stateno = 620
trigger16 = MoveContact
trigger17 = Stateno = 630
trigger17 = MoveContact
trigger18 = Stateno = 640
trigger18 = MoveContact
trigger19 = Stateno = 650
trigger19 = MoveContact
trigger20 = Stateno = 660
trigger20 = MoveContact

; "SuperShot"
[State -1, ]
type = ChangeState
value = 1383
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C || StateType = A
triggerall = command = "SuperBuble!"
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger14 = stateno = 2440
trigger15 = stateno = 2445
trigger16 = stateno = 4036
trigger17 = stateno = 1331
trigger18 = stateno = 1330
trigger19 = stateno = 1380
trigger20 = stateno = 3031
trigger21 = stateno = 4065
trigger22 = stateno = 1270
trigger23= stateno = 4069
trigger24 = stateno = 7025
trigger25 = stateno = 4073
trigger26 = stateno = 4057
trigger27 = stateno = 4079
trigger28 = stateno = 4055
trigger29 = stateno = 4165
trigger30 = Stateno = 600
trigger30 = MoveContact
trigger31 = Stateno = 610
trigger31 = MoveContact
trigger32 = Stateno = 620
trigger33 = Stateno = 630
trigger33 = MoveContact
trigger34 = stateno = 640
trigger34 = MoveContact
trigger35 = stateno = 4102
trigger36 = stateno = 1300
trigger37 = stateno = 650
trigger37 = MoveContact
trigger38 = stateno = 1310
trigger39 = stateno = 1390
trigger40 = stateno = 1311
trigger41 = stateno = 4278
trigger41 = time >= 30
trigger42 = stateno = 660
trigger43 = stateno = 1270
trigger44 = stateno = 1281
trigger45 = stateno = 1283
trigger46 = stateno = 4290
trigger47 = stateno = 2448
trigger48 = stateno = 2000
trigger49 = stateno = 2001
trigger50 = stateno = 1323

; "SuperShot"
[State -1, ]
type = ChangeState
value = 1383
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C || StateType = A
triggerall = command = "easysupyz";"Bucky"
triggerall = command = "holddown"
triggerall = Var(59) = 1
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger14 = stateno = 2440
trigger15 = stateno = 2445
trigger16 = stateno = 4036
trigger17 = stateno = 1331
trigger18 = stateno = 1330
trigger19 = stateno = 1380
trigger20 = stateno = 3031
trigger21 = stateno = 4065
trigger22 = stateno = 1270
trigger23= stateno = 4069
trigger24 = stateno = 7025
trigger25 = stateno = 4073
trigger26 = stateno = 4057
trigger27 = stateno = 4079
trigger28 = stateno = 4055
trigger29 = stateno = 4165
trigger30 = Stateno = 600
trigger30 = MoveContact
trigger31 = Stateno = 610
trigger31 = MoveContact
trigger32 = Stateno = 620
trigger33 = Stateno = 630
trigger33 = MoveContact
trigger34 = stateno = 640
trigger34 = MoveContact
trigger35 = stateno = 4102
trigger36 = stateno = 1300
trigger37 = stateno = 650
trigger37 = MoveContact
trigger38 = stateno = 1310
trigger39 = stateno = 1390
trigger40 = stateno = 1311
trigger41 = stateno = 4278
trigger41 = time >= 30
trigger42 = stateno = 660
trigger43 = stateno = 1270
trigger44 = stateno = 1281
trigger45 = stateno = 1283
trigger46 = stateno = 4290
trigger47 = stateno = 2448
trigger48 = stateno = 2000
trigger49 = stateno = 2001
trigger50 = stateno = 1323


; "SuperBuble!"
[State -1, ]
type = ChangeState
value = 4288
triggerall = numhelper(5002) = 1
triggerall = StateType = S || StateType = C || StateType = A
triggerall = command = "Spinx"
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 220
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 240
trigger5 = MoveContact
trigger6 = stateno = 250
;trigger6 = MoveContact
trigger7 = stateno = 400
trigger7 = MoveContact
trigger8 = stateno = 410
trigger8 = MoveContact
trigger9 = stateno = 420
;trigger9 = MoveContact
trigger10 = stateno = 430
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 600
trigger14 = MoveContact
trigger15 = stateno = 610
trigger15 = MoveContact
trigger16 = stateno = 620
trigger16 = MoveContact
trigger17 = Stateno = 630
trigger17 = MoveContact
trigger18 = Stateno = 640
trigger18 = MoveContact
trigger19 = Stateno = 650
trigger19 = MoveContact
trigger20 = stateno = 1270
trigger21 = stateno = 1281
trigger22 = stateno = 1283
trigger23 = stateno = 4103
trigger24 = stateno = 4104
trigger25 = stateno = 4105
trigger26 = stateno = 4106
trigger27 = stateno = 4107
trigger28 = stateno = 4108
trigger29 = stateno = 4109
trigger30 = Stateno = 210
trigger31 = Stateno = 1302
trigger32 = Stateno = 1306
trigger33 = Stateno = 1382
trigger34 = Stateno = 1412
trigger35 = Stateno = 4290

; "SuperBuble!"
[State -1, ]
type = ChangeState
value = 4288
triggerall = numhelper(5002) = 1
triggerall = StateType = S || StateType = C || StateType = A
triggerall = command = "easysupyz";"Bucky"
triggerall = command = "holddown"
triggerall = Var(59) = 1
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 220
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 240
trigger5 = MoveContact
trigger6 = stateno = 250
;trigger6 = MoveContact
trigger7 = stateno = 400
trigger7 = MoveContact
trigger8 = stateno = 410
trigger8 = MoveContact
trigger9 = stateno = 420
;trigger9 = MoveContact
trigger10 = stateno = 430
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 600
trigger14 = MoveContact
trigger15 = stateno = 610
trigger15 = MoveContact
trigger16 = stateno = 620
trigger16 = MoveContact
trigger17 = Stateno = 630
trigger17 = MoveContact
trigger18 = Stateno = 640
trigger18 = MoveContact
trigger19 = Stateno = 650
trigger19 = MoveContact
trigger20 = stateno = 1270
trigger21 = stateno = 1281
trigger22 = stateno = 1283
trigger23 = stateno = 4103
trigger24 = stateno = 4104
trigger25 = stateno = 4105
trigger26 = stateno = 4106
trigger27 = stateno = 4107
trigger28 = stateno = 4108
trigger29 = stateno = 4109
trigger30 = Stateno = 210
trigger31 = Stateno = 1302
trigger32 = Stateno = 1306
trigger33 = Stateno = 1382
trigger34 = Stateno = 1412
trigger35 = Stateno = 4290

;------------------------------------------

; Assist Wimpy
[State -1,]
type = ChangeState
value = 2448
triggerall = numhelper(5001) = 0
triggerall = numhelper(5002) = 0
triggerall = StateType = A
triggerall = Command = "Fart"
trigger1 = ctrl
trigger2 = StateNo = 600
trigger2 = Movecontact
trigger3 = StateNo = 610
trigger3 = Movecontact
trigger4 = StateNo = 620
trigger5 = StateNo = 630
trigger5 = Movecontact
trigger6 = StateNo = 640
trigger6 = Movecontact
trigger7 = StateNo = 650
trigger7 = Movecontact

[State -1,]
type = ChangeState
value = 2448
triggerall = numhelper(5001) = 0
triggerall = numhelper(5002) = 0
triggerall = StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyz";"Bucky"
triggerall = command != "holdfwd"
triggerall = stateno != 720
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = StateNo = 4096

;------------------------------------------

[State -1,]
type = null;ChangeState
value = 4241
triggerall = command = "Spinx"
triggerall = power >= 1000
triggerall = statetype = A || statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
trigger12 = MoveContact
trigger13 = stateno = 420
trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = stateno = 2440
trigger24 = stateno = 2445
trigger25 = stateno = 1310
trigger26 = stateno = 1331
trigger27 = stateno = 1330
trigger28 = stateno = 1380
trigger29 = stateno = 3031
trigger30 = stateno = 4036
trigger31 = stateno = 1325;11
trigger32 = stateno = 1270
trigger33 = stateno = 4103
trigger34 = stateno = 4104
trigger35 = stateno = 4105
trigger36 = stateno = 4106
trigger37 = stateno = 4107
trigger38 = stateno = 4108
trigger39 = stateno = 4109
trigger40 = stateno = 4110
trigger41 = stateno = 4065
trigger42 = stateno = 4102
trigger43 = stateno = 1390
trigger44 = stateno = 1391

;------------------------------------------

[State -1,]
type = ChangeState
value = 4096
triggerall = command = "BrownAlbert"
triggerall = statetype = A || statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 210
trigger3 = MoveContact
trigger4 = stateno = 220
;trigger4 = MoveContact
trigger5 = stateno = 230
trigger5 = MoveContact
trigger6 = stateno = 240
trigger6 = MoveContact
trigger7 = stateno = 250
trigger7 = MoveContact
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = !MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = Stateno = 600
trigger14 = MoveContact
trigger15 = Stateno = 610
trigger15 = MoveContact
trigger16 = Stateno = 620
;trigger16 = MoveContact
trigger17 = Stateno = 630
trigger17 = MoveContact
trigger18 = stateno = 640
trigger18 = MoveContact
trigger19 = stateno = 650
;trigger19 = MoveContact
trigger20 = stateno = 660

;-------------------------------------------------
; Assist Bluto
[State -1,]
type = ChangeState
value = 1311
triggerall = Command = "Assist2"
triggerall = statetype = S || Statetype = C
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact


; Assist Bluto
[State -1,]
type = ChangeState
value = 1311
triggerall = command = "easyy";"Bucky"
triggerall = command != "holdback"
triggerall = Var(59) = 1
triggerall = statetype = S || Statetype = C
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact

;-------------------------------------------



; Assist Bluto
[State -1,]
type = ChangeState
value = 1315
triggerall = Command = "Assist2"
triggerall = statetype = S || Statetype = C
triggerall = NumHelper(5001) = 1
;triggerall = NumHelper(1319) = 0
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact


[State -1,]
type = ChangeState
value = 1315
triggerall = command = "easyy";"Bucky"
triggerall = command != "holdback"
triggerall = command != "holdfwd"
triggerall = Var(59) = 1
triggerall = statetype = S || Statetype = C
triggerall = NumHelper(5001) = 1
;triggerall = NumHelper(1319) = 0
trigger1 = ctrl
trigger2 = stateno = 210
trigger2 = Time >=15
trigger3 = stateno = 4096


;------------------------------------------

; Assist Bluto
[State -1,]
type = ChangeState
value = 1306
triggerall = Command = "Assist2"
triggerall = statetype = S || Statetype = C
triggerall = NumHelper(5002) = 1
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact

;-------------------------------

; "SuperBuble!"
[State -1, ]
type = null;ChangeState
value = 4269
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C || StateType = A
triggerall = command = "Avalanche"
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
trigger12 = MoveContact
trigger13 = stateno = 420
trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = stateno = 2440
trigger24 = stateno = 2445
trigger25 = stateno = 1310
trigger26 = stateno = 1331
trigger27 = stateno = 1330
trigger28 = stateno = 1380
trigger29 = stateno = 3031
trigger30 = stateno = 4036
trigger31 = stateno = 1325;11
trigger32 = stateno = 1270
trigger33 = stateno = 4103
trigger34 = stateno = 4104
trigger35 = stateno = 4105
trigger36 = stateno = 4106
trigger37 = stateno = 4107
trigger38 = stateno = 4108
trigger39 = stateno = 4109
trigger40 = stateno = 4110
trigger41 = stateno = 4065
trigger42 = stateno = 4102
trigger43 = stateno = 1390
trigger44 = stateno = 1391

;-------------------------------

[State -1,AirRunUF]
type = ChangeState
value = 4103
triggerall = command = "UFRun"
;triggerall = statetype = A
triggerall = var(11) = 0
triggerall = NumHelper(4097) = 0
trigger1 = ctrl
trigger2 = Stateno = 600
trigger2 = MoveContact
trigger3 = Stateno = 610
trigger3 = MoveContact
trigger4 = Stateno = 620
trigger4 = MoveContact
trigger5 = Stateno = 630
trigger5 = MoveContact
trigger6 = stateno = 640
trigger6 = MoveContact
trigger7 = stateno = 650
;trigger7 = MoveContact


;------------------------------------------
[State -1,AirRunUF]
type = ChangeState
value = 4104
triggerall = command = "DFRun"
triggerall = statetype = A
triggerall = NumHelper(4097) = 0
trigger1 = ctrl
trigger2 = Stateno = 600
trigger2 = MoveContact
trigger3 = Stateno = 610
trigger3 = MoveContact
trigger4 = Stateno = 620
trigger4 = MoveContact
trigger5 = Stateno = 630
trigger5 = MoveContact
trigger6 = stateno = 640
trigger6 = MoveContact
trigger7 = stateno = 650
;trigger7 = MoveContact




;------------------------------------------
[State -1,AirRunUF]
type = ChangeState
value = 4105
triggerall = command = "DBRun"
triggerall = statetype = A
triggerall = NumHelper(4097) = 0
trigger1 = ctrl
trigger2 = Stateno = 600
trigger2 = MoveContact
trigger3 = Stateno = 610
trigger3 = MoveContact
trigger4 = Stateno = 620
trigger4 = MoveContact
trigger5 = Stateno = 630
trigger5 = MoveContact
trigger6 = stateno = 640
trigger6 = MoveContact
trigger7 = stateno = 650
;trigger7 = MoveContact



;------------------------------------------
[State -1,AirRunUF]
type = ChangeState
value = 4106
triggerall = command = "UBRun"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = Stateno = 600
trigger2 = MoveContact
trigger3 = Stateno = 610
trigger3 = MoveContact
trigger4 = Stateno = 620
trigger4 = MoveContact
trigger5 = Stateno = 630
trigger5 = MoveContact
trigger6 = stateno = 640
trigger6 = MoveContact
trigger7 = stateno = 650
;trigger7 = MoveContact



;------------------------------------------
[State -1,AirRunUF]
type = ChangeState
value = 4107
triggerall = command = "FRun"
triggerall = statetype = A
triggerall = NumHelper(4097) = 0
trigger1 = ctrl
trigger2 = Stateno = 600
trigger2 = MoveContact
trigger3 = Stateno = 610
trigger3 = MoveContact
trigger4 = Stateno = 620
trigger4 = MoveContact
trigger5 = Stateno = 630
trigger5 = MoveContact
trigger6 = stateno = 640
trigger6 = MoveContact
trigger7 = stateno = 650
;trigger7 = MoveContact

;------------------------------------------
[State -1,AirRunUF]
type = ChangeState
value = 4108
triggerall = command = "BRun"
triggerall = Prevstateno != 2451
triggerall = statetype = A
triggerall = NumHelper(4097) = 0
trigger1 = ctrl
trigger2 = Stateno = 600
trigger2 = MoveContact
trigger3 = Stateno = 610
trigger3 = MoveContact
trigger4 = Stateno = 620
trigger4 = MoveContact
trigger5 = Stateno = 630
trigger5 = MoveContact
trigger6 = stateno = 640
trigger6 = MoveContact
trigger7 = stateno = 650
;trigger7 = MoveContact


;------------------------------------------
[State -1,AirRunUF]
type = ChangeState
value = 4109
triggerall = command = "URun"
triggerall = statetype = A
triggerall = NumHelper(4097) = 0
trigger1 = ctrl
trigger2 = Stateno = 600
trigger2 = MoveContact
trigger3 = Stateno = 610
trigger3 = MoveContact
trigger4 = Stateno = 620
trigger4 = MoveContact
trigger5 = Stateno = 630
trigger5 = MoveContact
trigger6 = stateno = 640
trigger6 = MoveContact
trigger7 = stateno = 650
;trigger7 = MoveContact


------------------------------------------------

[State -1,AirRunUF]
type = ChangeState
value = 4110
triggerall = command = "DRun"
triggerall = statetype = A
triggerall = NumHelper(4097) = 0
trigger1 = ctrl
trigger2 = Stateno = 600
trigger2 = MoveContact
trigger3 = Stateno = 610
trigger3 = MoveContact
trigger4 = Stateno = 620
trigger4 = MoveContact
trigger5 = Stateno = 630
trigger5 = MoveContact
trigger6 = stateno = 640
trigger6 = MoveContact
trigger7 = stateno = 650
;trigger7 = MoveContact


;------------------------------------------------


;----------------------------------------------------------------------------


; Assist Wimpy
[State -1,]
type = ChangeState
value = 3025
triggerall = Command = "Assist"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = numhelper(3024) = 0
triggerall = numhelper(3029) = 0
triggerall = numhelper(4056) = 0
triggerall = statetype = S || Statetype = C || Statetype = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger14 = stateno = 661
trigger14 = MoveContact
trigger15 = Stateno = 600
trigger15 = MoveContact
trigger16 = Stateno = 610
trigger16 = MoveContact
trigger17 = Stateno = 620
trigger17 = MoveContact
trigger18 = Stateno = 630
trigger18 = MoveContact
trigger19 = stateno = 640
trigger19 = MoveContact
trigger20 = stateno = 650
trigger20 = MoveContact



; Assist Wimpy
[State -1,]
type = ChangeState
value = 3025
triggerall = command = "easya";"Bucky"
triggerall = command != "holdfwd"
triggerall = command != "holdback"
triggerall = Var(59) = 1
triggerall = StateNo != 720
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = numhelper(3024) = 0
triggerall = numhelper(3029) = 0
triggerall = numhelper(4056) = 0
triggerall = statetype = S || Statetype = C || Statetype = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger14 = stateno = 661
trigger14 = MoveContact
trigger15 = Stateno = 600
trigger15 = MoveContact
trigger16 = Stateno = 610
trigger16 = MoveContact
trigger17 = Stateno = 620
trigger17 = MoveContact
trigger18 = Stateno = 640
trigger18 = MoveContact
trigger19 = stateno = 640
trigger19 = MoveContact
trigger20 = stateno = 650
trigger20 = MoveContact


;------------------------------------------------

[State -1,]
type = ChangeState
value = 2455
triggerall = command = "Gum"
triggerall = NumHelper(5001) = 1
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger14 = stateno = 661
trigger14 = MoveContact
trigger15 = Stateno = 600
trigger15 = MoveContact
trigger16 = Stateno = 610
trigger16 = MoveContact
trigger17 = Stateno = 620
trigger17 = MoveContact
trigger18 = Stateno = 630
trigger18 = MoveContact
trigger19 = stateno = 640
trigger19 = MoveContact
trigger20 = stateno = 650
trigger20 = MoveContact

[State -1, ]
type = ChangeState
value = 1412
triggerall = command = "Gum"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger14 = stateno = 661
trigger14 = MoveContact
trigger15 = Stateno = 600
trigger15 = MoveContact
trigger16 = Stateno = 610
trigger16 = MoveContact
trigger17 = Stateno = 620
trigger17 = MoveContact
trigger18 = Stateno = 630
trigger18 = MoveContact
trigger19 = stateno = 640
trigger19 = MoveContact
trigger20 = stateno = 650
trigger20 = MoveContact
trigger21 = Stateno = 1382
trigger22 = Stateno = 1270
trigger23 = Stateno = 1281
trigger24 = Stateno = 1283

;----------------------------------------------------------------------------


;---------------------------------------------------------------------------
; Assist Bluto
[State -1, ]
type = ChangeState
value = 3029
;triggerall = NumHelper(3030) = 0
triggerall = Command = "Assist3"
triggerall = statetype = S || Statetype = C
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 210
trigger3 = MoveContact
trigger4 = stateno = 220
;trigger4 = MoveContact
trigger5 = stateno = 230
trigger5 = MoveContact
trigger6 = stateno = 240
trigger6 = MoveContact
trigger7 = stateno = 250
trigger7 = MoveContact
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger11 = stateno = 430
trigger11 = !MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 1281
trigger15 = stateno = 1283

[State 8017]
type = null;Helper
;triggerall = numhelper(5005) = 0
triggerall = numhelper(5000) = 0
trigger1 = numhelper(5002) = 0
trigger1 = numhelper(5001) = 0
trigger1 = Gametime = 10
trigger2 = numhelper(5000) = 0
trigger2 = numhelper(5002) = 0
trigger2 = numhelper(5001) = 0
;trigger1 = Gametime = 10
id = 5000
helpertype = normal
postype = p1
pos = 52,0
stateno = 1393
keyctrl = 1
ownpal = 1
;supermovetime = 9999
size.xscale= .3
size.yscale= .2

[State 8017]
type = null;Helper
triggerall = numhelper(5033) = 0
trigger1 = Gametime%0 = 0
trigger2 = command = "Donald"
id = 5033
helpertype = normal
postype = p2
pos = 370,-100
stateno = 4139
keyctrl = 1
ownpal = 1
;supermovetime = 9999

;------------------------------------------

; "Fart"
[State -1, ]
type = ChangeState
value = 1310
triggerall = command = "Donald"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
;triggerall = numhelper(3033) = 0
triggerall = numhelper(3024) = 0
triggerall = numhelper(3029) = 0
triggerall = numhelper(4056) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = stateno = 5120
trigger24 = stateno = 1270
trigger25 = stateno = 1281
trigger26 = stateno = 4073
trigger27 = stateno = 4057
trigger28 = stateno = 4079
trigger29 = stateno = 4055
trigger30 = stateno = 4165
trigger31 = stateno = 1283


[State -1, ]
type = ChangeState
value = 1310
triggerall = command = "easyz";"Bucky"
triggerall = command = "holdfwd"
triggerall = Var(59) = 1
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
;triggerall = numhelper(3033) = 0
triggerall = numhelper(3024) = 0
triggerall = numhelper(3029) = 0
triggerall = numhelper(4056) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = stateno = 5120
trigger24 = stateno = 1270
trigger25 = stateno = 1281
trigger26 = stateno = 4073
trigger27 = stateno = 4057
trigger28 = stateno = 4079
trigger29 = stateno = 4055
trigger30 = stateno = 4165
trigger31 = stateno = 1283

;------------------------------------------

; "Fart"
[State -1, ]
type = ChangeState
value = 4278
triggerall = command = "Phant"
triggerall = NumHelper(5001) = 1
;triggerall = NumHelper(5002) = 0
triggerall = numhelper(4287) = 0
triggerall = numhelper(4279) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 661
trigger14 = MoveContact
trigger15 = Stateno = 600
trigger15 = MoveContact
trigger16 = Stateno = 610
trigger16 = MoveContact
trigger17 = Stateno = 620
;trigger17 = MoveContact
trigger18 = Stateno = 630
trigger18 = MoveContact
trigger19 = stateno = 640
trigger19 = MoveContact
trigger20 = stateno = 650
trigger20 = MoveContact


[State -1, ]
type = ChangeState
value = 4278
triggerall = command = "easyy";"Bucky"
triggerall = command = "holdfwd"
triggerall = Var(59) = 1
triggerall = NumHelper(5001) = 1
;triggerall = NumHelper(5002) = 0
triggerall = numhelper(4287) = 0
triggerall = numhelper(4279) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = Stateno = 4096

;-------------------------------------------------
; "Teleport"
[State -1, ]
type = ChangeState
value = 1351
triggerall = command = "Slash"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = numhelper(4281) = 0
triggerall = StateType = S || StateType = C ;|| StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact


; "Teleport"
[State -1, ]
type = ChangeState
value = 1351
triggerall = command = "easyc";"Bucky"
triggerall = command = "holdback"
triggerall = Var(59) = 1
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = numhelper(4281) = 0
triggerall = StateType = S || StateType = C ;|| StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact

;--------------------------------------------

; "Teleport"
[State -1, ]
type = ChangeState
value = 1360
triggerall = command = "Slash2"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C ;|| StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact



; "Teleport"
[State -1, ]
type = ChangeState
value = 1360
triggerall = command = "easya";"Bucky"
triggerall = command = "holdback"
triggerall = Var(59) = 1
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C ;|| StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact

;--------------------------------------------

; "Teleport"
[State -1, ]
type = ChangeState
value = 1362
triggerall = command = "Slash3"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C ;|| StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact



[State -1, ]
type = ChangeState
value = 1362
triggerall = command = "easyb";"Bucky"
triggerall = command = "holdback"
triggerall = Var(59) = 1
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C ;|| StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact


;------------------------------------------

; Assist Wimpy
[State -1,]
type = ChangeState
value = 2445
triggerall = NumHelper(5001) = 1
triggerall = NumHelper(5002) = 0
triggerall = Command = "Phatsolo"
trigger1 = statetype = S || Statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 210
trigger15 = MoveContact

; Assist Wimpy
[State -1,]
type = ChangeState
value = 2445
triggerall = NumHelper(5001) = 1
triggerall = NumHelper(5002) = 0
triggerall = command = "easyc";"Bucky"
triggerall = command != "holdfwd"
triggerall = Var(59) = 1
trigger1 = statetype = S || Statetype = C
trigger1 = ctrl

; Assist Wimpy
[State -1,]
type = ChangeState
value = 2455
triggerall = NumHelper(5001) = 1
triggerall = NumHelper(5002) = 0
triggerall = command = "easyb";"Bucky"
triggerall = command != "holdfwd"
triggerall = Var(59) = 1
trigger1 = statetype = S || Statetype = C
trigger1 = ctrl

;-----------------------------------------

; Assist Wimpy
[State -1,]
type = ChangeState
value = 1410
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = Command = "Phatsolo"
trigger1 = statetype = S || Statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 210
trigger15 = MoveContact


;------------------------------------------

; Bullet Array
[State -1,]
type = ChangeState
value = 2440
triggerall = numhelper(5002) = 1; || numhelper(5001) = 1
triggerall = numhelper(4094) = 0
triggerall = Command = "Array"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = StateNo = 600
trigger2 = Movecontact = 1
trigger3 = StateNo = 610
trigger3 = Movecontact = 1
trigger4 = StateNo = 620
;trigger4 = Movecontact = 1
trigger5 = StateNo = 630
trigger5 = Movecontact = 1
trigger6 = StateNo = 640
trigger6 = Movecontact = 1
trigger7 = StateNo = 650
trigger7 = Movecontact = 1



;---------------------------------


 "Gum"
[State -1, ]
type = ChangeState
value = 2000
triggerall = command = "dragon3"
triggerall = numhelper(5001) = 0
triggerall = numhelper(5002) = 0
triggerall = StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact


 "Gum"
[State -1, ]
type = ChangeState
value = 2000
triggerall = command = "easyx";"Bucky"
triggerall = command != "holdfwd"
triggerall = stateno != 720
triggerall = Var(59) = 1
triggerall = numhelper(5001) = 0
triggerall = numhelper(5002) = 0
triggerall = StateType = A
trigger1 = ctrl
trigger2 = Stateno = 4096
;trigger2 = Stateno = 600
;trigger2 = MoveContact
;trigger3 = Stateno = 610
;trigger3 = MoveContact
;trigger4= Stateno = 620
;trigger19 = MoveContact
;trigger5 = Stateno = 630
;trigger5 = MoveContact
;trigger6 = stateno = 640
;trigger6 = MoveContact
;trigger7 = stateno = 650
;trigger7 = MoveContact


;----------------------------------------


 "Gum"
[State -1, ]
type = ChangeState
value = 2001
triggerall = command = "Bucky"
triggerall = numhelper(5001) = 0
triggerall = numhelper(5002) = 0
triggerall = StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact




[State -1, ]
type = ChangeState
value = 2001
triggerall = command = "easyy";"Bucky"
triggerall = command != "holdfwd"
triggerall = command != "holdback"
triggerall = stateno != 720
triggerall = Var(59) = 1
triggerall = numhelper(5001) = 0
triggerall = numhelper(5002) = 0
triggerall = StateType = A
trigger1 = ctrl
trigger2 = Stateno = 4096
;trigger2 = MoveContact
;trigger3 = Stateno = 610
;trigger3 = MoveContact
;trigger4= Stateno = 620
;trigger19 = MoveContact
;trigger5 = Stateno = 630
;trigger5 = MoveContact
;trigger6 = stateno = 640
;trigger6 = MoveContact
;trigger7 = stateno = 650
;trigger7 = MoveContact


;---------------------------------------------------------------------------

; Blue (light)
[State -1, ]
type = ChangeState
value = 1300
triggerall = command = "Fart";"Bucky"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C; || StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact


; Blue (light)
[State -1, ]
type = ChangeState
value = 1300
triggerall = command = "easyz";"Bucky"
triggerall = command != "holdback"
triggerall = Var(59) = 1
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C; || StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact



;------------------------------------------------------------


; Red (light)
[State -1, ]
type = ChangeState
value = 1302
triggerall = command = "Fart";"Bucky"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C; || StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = stateno = 5120
trigger24 = stateno = 4069
trigger25 = stateno = 7025
trigger26 = stateno = 4073
trigger27 = stateno = 4057
trigger28 = stateno = 4079
trigger29 = stateno = 4055
trigger30 = stateno = 4165


[State -1,]
type = ChangeState
value = 1302
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C; || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyz";"Bucky"
triggerall = command != "holdback"
trigger1 = ctrl
trigger2 = StateNo = 4096
trigger3 = stateno = 220
trigger3 = Time >= 10

[State -1,]
type = ChangeState
value = 4295
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = A; || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyz";"Bucky"
triggerall = command != "holdback"
trigger1 = ctrl
trigger2 = StateNo = 4096
trigger3 = stateno = 620
trigger3 = Time >= 7
trigger3 = MoveContact = 0

[State -1,]
type = ChangeState
value = 1306
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C; || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyy";"Bucky"
triggerall = command != "holdback"
trigger1 = ctrl
;trigger2 = StateNo = 4096
trigger2 = stateno = 210
trigger2 = Time >= 10

[State -1,]
type = ChangeState
value = 1405
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C; || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyx";"Bucky"
triggerall = command != "holdback"
trigger1 = ctrl
;trigger2 = StateNo = 4096
trigger2 = stateno = 210
trigger2 = Time >= 10

[State -1,]
type = ChangeState
value = 2440
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = A; || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyy";"Bucky"
triggerall = command != "holdback"
trigger1 = ctrl
trigger2 = StateNo = 4096
trigger3 = stateno = 610
trigger3 = Time >= 11
trigger3 = MoveContact = 0

[State -1,]
type = ChangeState
value = 1281
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C; || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easya";"Bucky"
;triggerall = command != "holdback"
trigger1 = ctrl
;trigger2 = StateNo = 4096
trigger2 = stateno = 230
trigger2 = Time >= 10

[State -1,]
type = ChangeState
value = 1283
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C; || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyb";"Bucky"
triggerall = command != "holdfwd"
trigger1 = ctrl
;trigger2 = StateNo = 4096
trigger2 = stateno = 240
trigger2 = Time >= 10
trigger3 = StateNo = 1281

[State -1,]
type = ChangeState
value = 1270
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C; || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyc";"Bucky"
triggerall = command != "holdfwd"
trigger1 = ctrl
;trigger2 = StateNo = 4096
trigger2 = stateno = 250
trigger2 = Time >= 10
trigger3 = StateNo = 1283


[State -1,]
type = ChangeState
value = 1412
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyb";"Bucky"
triggerall = command = "holdfwd"
trigger1 = ctrl
trigger2 = StateNo = 4096
trigger3 = stateno = 640
trigger3 = Time >= 11
trigger3 = MoveContact = 0

[State -1,]
type = ChangeState
value = 1410
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C; || StateType = A
triggerall = Var(59) = 1
triggerall = command = "easyc";"Bucky"
triggerall = command = "holdfwd"
trigger1 = ctrl
trigger2 = StateNo = 4096
trigger3 = stateno = 650
trigger3 = Time >= 11
trigger3 = MoveContact = 0



;---------------------------------------------

; Red (light)
[State -1, ]
type = ChangeState
value = 4295
triggerall = command = "Powerfly";"Bucky"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = stateno = 5120
trigger24 = stateno = 4069
trigger25 = stateno = 7025
trigger26 = stateno = 4073
trigger27 = stateno = 4057
trigger28 = stateno = 4079
trigger29 = stateno = 4055
trigger30 = stateno = 4165
trigger31 = stateno = 1281
trigger32 = stateno = 1283
trigger33 = stateno = 1270

; Red (light)
[State -1, ]
type = ChangeState
value = 1405
triggerall = command = "dragon3"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact

; Red (light)
[State -1, ]
type = ChangeState
value = 1330
triggerall = command = "Fart";"Bucky"
triggerall = NumHelper(5001) = 1
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
;trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
;trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = stateno = 5120
trigger24 = stateno = 4069
trigger25 = stateno = 7025
trigger26 = stateno = 4073
trigger27 = stateno = 4057
trigger28 = stateno = 4079
trigger29 = stateno = 4055
trigger30 = stateno = 4165

; Red (light)
[State -1, ]
type = ChangeState
value = 1330
triggerall = command = "easyz";"Bucky"
triggerall = command != "holdback"
triggerall = Var(59) = 1
triggerall = NumHelper(5001) = 1
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = Stateno = 4096

;----------------------------------------------------------------------------
; Milli Roll
[State -1,]
type = ChangeState
value = 1314
triggerall = command = "Mud"
triggerall = NumHelper(5001) = 1
;triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C
triggerall = Stateno != 740
trigger1 = ctrl

; Power Shoulder
[State -1,]
type = ChangeState
value = 4290
triggerall = command = "Mud"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C
triggerall = Stateno != 740
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 210
trigger2 = MoveContact
trigger4 = stateno = 220
trigger5 = stateno = 230
trigger5 = MoveContact
trigger6 = stateno = 240
trigger6 = MoveContact
trigger7 = stateno = 250
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 1361
trigger15 = stateno = 1363
trigger16 = stateno = 1358

; Desintegrate
[State -1,]
type = ChangeState
value = 4291
triggerall = command = "russel"
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C
triggerall = Stateno != 740
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 210
trigger2 = MoveContact
trigger4 = stateno = 220
trigger5 = stateno = 230
trigger5 = MoveContact
trigger6 = stateno = 240
trigger6 = MoveContact
trigger7 = stateno = 250
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 1281
trigger15 = stateno = 1283

[State -1,]
type = ChangeState
value = 4291
triggerall = command = "easyb";"Bucky"
triggerall = command != "holdfwd"
triggerall = Var(59) = 1
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = StateType = S || StateType = C
triggerall = Stateno != 740
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 210
trigger2 = MoveContact
trigger4 = stateno = 220
trigger5 = stateno = 230
trigger5 = MoveContact
trigger6 = stateno = 240
trigger6 = MoveContact
trigger7 = stateno = 250
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 1281
trigger15 = stateno = 1283


;-------------------------------------------

; Dragon Punch (hard)
[State -1, ]
type = null;ChangeState
value = 4267
triggerall = command = "Mud"
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 210
trigger3 = MoveContact
trigger4 = stateno = 220
trigger4 = MoveContact
trigger5 = stateno = 230
trigger5 = MoveContact
trigger6 = stateno = 240
trigger6 = MoveContact
trigger7 = stateno = 250
trigger7 = MoveContact
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact

;----------------------------------------------------------------------------
 "Gum"
[State -1, ]
type = ChangeState
value = 1380
triggerall = command = "dragon3"
triggerall = NumHelper(1029) = 0
triggerall = NumHelper(100) = 0
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = NumHelper(4191) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger14 = stateno = 661
trigger14 = MoveContact
trigger15 = StateNo = 600
trigger15 = Movecontact = 1
trigger16 = StateNo = 610
trigger16 = Movecontact = 1
trigger17 = StateNo = 620
trigger17 = Movecontact = 1
trigger18 = StateNo = 630
trigger18 = Movecontact = 1
trigger19 = StateNo = 640
trigger19 = Movecontact = 1
trigger20 = StateNo = 650
trigger20 = Movecontact = 1



[State -1, ]
type = ChangeState
value = 1380
triggerall = command = "easyx";"Bucky"
triggerall = command != "holdback"
triggerall = Var(59) = 1
triggerall = NumHelper(1029) = 0
triggerall = NumHelper(100) = 0
triggerall = NumHelper(5001) = 0
triggerall = NumHelper(5002) = 0
triggerall = NumHelper(4191) = 0
triggerall = StateType = S || StateType = C; || StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger14 = stateno = 661
trigger14 = MoveContact
trigger15 = StateNo = 600
trigger15 = Movecontact = 1
trigger16 = StateNo = 610
trigger16 = Movecontact = 1
trigger17 = StateNo = 620
trigger17 = Movecontact = 1
trigger18 = StateNo = 630
trigger18 = Movecontact = 1
trigger19 = StateNo = 640
trigger19 = Movecontact = 1
trigger20 = StateNo = 650
trigger20 = Movecontact = 1

;----------------------------------------------------------------------------
 "Gum"
[State -1, ]
type = ChangeState
value = 1382
triggerall = command = "razzle";
triggerall = NumHelper(5002) = 1
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger14 = stateno = 661
trigger14 = MoveContact
trigger15 = StateNo = 600
trigger15 = Movecontact = 1
trigger16 = StateNo = 610
trigger16 = Movecontact = 1
trigger17 = StateNo = 620
trigger17 = Movecontact = 1
trigger18 = StateNo = 630
trigger18 = Movecontact = 1
trigger19 = StateNo = 640
trigger19 = Movecontact = 1
trigger20 = StateNo = 650
trigger20 = Movecontact = 1
trigger21 = StateNo = 1281
trigger22 = StateNo = 1283
trigger23 = StateNo = 1270

 "Gum"
[State -1, ]
type = ChangeState
value = 1317
triggerall = command = "dragon3"
triggerall = NumHelper(1029) = 0
triggerall = NumHelper(100) = 0
triggerall = NumHelper(5001) = 1
triggerall = NumHelper(4191) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact





 "Gum"
[State -1, ]
type = ChangeState
value = 1317
triggerall = command = "easyx";"Bucky"
triggerall = command != "holdback"
triggerall = stateno != 720
triggerall = Var(59) = 1
triggerall = NumHelper(1029) = 0
triggerall = NumHelper(100) = 0
triggerall = NumHelper(5001) = 1
triggerall = NumHelper(4191) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = Stateno = 4096
;trigger2 = Stateno = 600
;trigger2 = MoveContact
;trigger3 = Stateno = 610
;trigger3 = MoveContact
;trigger4= Stateno = 620
;trigger19 = MoveContact
;trigger5 = Stateno = 630
;trigger5 = MoveContact
;trigger6 = stateno = 640
;trigger6 = MoveContact
;trigger7 = stateno = 650
;trigger7 = MoveContact


;----------------------------------------------------------------------------
  "Fart"
[State -1, ]
type = null;ChangeState
value = 1390
triggerall = command = "Fart"
triggerall = NumHelper(4094) = 0
triggerall = NumHelper(1001) = 0
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
;trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 4069
trigger15 = stateno = 7025
trigger16 = stateno = 4073
trigger17 = stateno = 4057
trigger18 = stateno = 4079
trigger19 = stateno = 4055
trigger20 = stateno = 4165


;----------------------------------------------------------------------------
  "Fart"
[State -1, ]
type = null;ChangeState
value = 1391
triggerall = command = "BRANG"
triggerall = NumHelper(4094) = 0
triggerall = NumHelper(1001) = 0
triggerall = StateType = S || StateType = C || StateType = A
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 4069
trigger15 = stateno = 7025
trigger16 = stateno = 4073
trigger17 = stateno = 4057
trigger18 = stateno = 4079
trigger19 = stateno = 4055
trigger20 = stateno = 4165
trigger21 = Stateno = 600
trigger21 = MoveContact
trigger22 = Stateno = 610
trigger22 = MoveContact
trigger23 = Stateno = 620
trigger23 = MoveContact
trigger24 = Stateno = 630
trigger24 = MoveContact
trigger25 = stateno = 640
trigger25 = MoveContact
trigger26 = stateno = 650
trigger26 = MoveContact

;----------------------------------------------------------------------------
  "Fart"
[State -1,]
type = ChangeState
value = 1283
triggerall = command = "Slash3";"razzle"
triggerall = numhelper(5002) = 1
triggerall = NumHelper(5001) = 0
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 4069
trigger15 = stateno = 7025
trigger16 = stateno = 4073
trigger17 = stateno = 4057
trigger18 = stateno = 4079
trigger19 = stateno = 4055
trigger20 = stateno = 4165
trigger21 = stateno = 1281

;-----------------------------------------

  "Fart"
[State -1,]
type = ChangeState
value = 1281
triggerall = command = "Slash2";"razzle"
triggerall = numhelper(5002) = 1
triggerall = NumHelper(5001) = 0
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
;trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 4069
trigger15 = stateno = 7025
trigger16 = stateno = 4073
trigger17 = stateno = 4057
trigger18 = stateno = 4079
trigger19 = stateno = 4055
trigger20 = stateno = 4165

;-----------------------------------------

  "Fart"
[State -1, ]
type = ChangeState
value = 1270
triggerall = command = "Slash";"razzle"
triggerall = numhelper(5002) = 1
triggerall = NumHelper(5001) = 0
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = Movecontact = 1
trigger3 = StateNo = 210
trigger3 = Movecontact = 1
trigger4 = StateNo = 220
;trigger4 = Movecontact = 1
trigger5 = StateNo = 230
trigger5 = Movecontact = 1
trigger6 = StateNo = 240
trigger6 = Movecontact = 1
trigger7 = StateNo = 250
trigger7 = Movecontact = 1
trigger8 = stateno = 400
trigger8 = MoveContact
trigger9 = stateno = 410
trigger9 = MoveContact
trigger10 = stateno = 420
;trigger10 = MoveContact
trigger11 = stateno = 430
trigger11 = MoveContact
trigger12 = stateno = 440
trigger12 = MoveContact
trigger13 = stateno = 450
trigger13 = MoveContact
trigger14 = stateno = 4069
trigger15 = stateno = 7025
trigger16 = stateno = 4073
trigger17 = stateno = 4057
trigger18 = stateno = 4079
trigger19 = stateno = 4055
trigger20 = stateno = 4165
trigger21 = stateno = 1281
trigger22 = stateno = 1283

;-------------------------------------------------------------

; Assist Bluto
[State -1,]
type = ChangeState
value = 1392
triggerall = Command = "dragon1"
triggerall = NumHelper(5000) = 0
triggerall = statetype = A || statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact


[State -1,]
type = ChangeState
value = 1392
triggerall = command = "easyx";"Bucky"
triggerall = command = "holdback"
triggerall = Var(59) = 1
triggerall = NumHelper(5000) = 0
triggerall = statetype = A || statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = StateNo = 4096

;-----------------------------------------

; Assist Bluto
[State -1,]
type = ChangeState
value = 1400
triggerall = Command = "Assist4"
triggerall = NumHelper(5001) = 0
triggerall = statetype = A || statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact


; Assist Bluto
[State -1,]
type = ChangeState
value = 1400
triggerall = command = "easyy";"Bucky"
triggerall = command = "holdback"
triggerall = Var(59) = 1
triggerall = NumHelper(5001) = 0
triggerall = statetype = A || statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = StateNo = 4096



;-------------------------------------------

; Assist Bluto
[State -1,]
type = ChangeState
value = 1402
triggerall = Command = "Assist5"
triggerall = NumHelper(5002) = 0
triggerall = statetype = A || statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact


[State -1,]
type = ChangeState
value = 1402
triggerall = command = "easyz";"Bucky"
triggerall = command = "holdback"
triggerall = Var(59) = 1
triggerall = NumHelper(5002) = 0
triggerall = statetype = A || statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 450
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = stateno = 445
trigger10 = MoveContact
trigger11 = stateno = 3024
trigger11 = !MoveContact
trigger12 = stateno = 220
;trigger12 = MoveContact
trigger13 = stateno = 420
;trigger13 = MoveContact
trigger14 = stateno = 250
trigger14 = MoveContact
trigger15 = stateno = 410
trigger15 = MoveContact
trigger16 = stateno = 210
trigger16 = MoveContact
trigger17 = Stateno = 600
trigger17 = MoveContact
trigger18 = Stateno = 610
trigger18 = MoveContact
trigger19 = Stateno = 620
;trigger19 = MoveContact
trigger20 = Stateno = 630
trigger20 = MoveContact
trigger21 = stateno = 640
trigger21 = MoveContact
trigger22 = stateno = 650
trigger22 = MoveContact
trigger23 = StateNo = 4096

;-----------------------------------------------

;  RollRecovery 
[State -1,]
type = ChangeState
value = 681
;trigger1 = ctrl
triggerall = pos Y >= 0 
triggerall = roundstate = 2
triggerall = Alive = 1
;triggerall = movetype = H
triggerall = Stateno = 5101 || Stateno = 5110 || Stateno = 5100 
trigger1 = command = "holdback"
trigger2 = command = "holdfwd"

;===========================================================================
;---------------------------------------------------------------------------
;Push Block (standing)  Thanks to BB Hood!
[State -1]
type = ChangeState
value = 860
triggerall = (command = "x" && command = "y") || (command = "y" && command = "z") || (command = "x" && command = "y" && command = "z")
trigger1 = stateno = [150,151]

;Push Block (crouching)
[State -1]
type = ChangeState
value = 870
triggerall = (command = "x" && command = "y") || (command = "y" && command = "z") || (command = "x" && command = "y" && command = "z")
trigger1 = stateno = [152,153]

;Push Block (aerial)
[State -1]
type = ChangeState
value = 880
triggerall = (command = "x" && command = "y") || (command = "y" && command = "z") || (command = "x" && command = "y" && command = "z")
trigger1 = stateno = 154
trigger2 = stateno = 155
trigger2 = Time <= 10

;===========================================================================
;---------------------------------------------------------------------------
; Air Dash
[State -1, Air Dash]
type = null;ChangeState
value = 740
triggerall = var(15) = 0
triggerall = stateno != 740
triggerall = PrevStateNo != 740
trigger1 = command = "FF"
trigger1 = StateType = A
trigger1 = ctrl
trigger2 = (command = "a" && command = "b") || (command = "b" && command = "c")
trigger2 = StateType = A
trigger2 = Ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BRun";"y" && command = "z";
;trigger1 = command = "HoldB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = statetype = S
trigger1 = command = "FF"
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = statetype = S
trigger1 = command = "y" && command = "z";"FRun";;
trigger1 = command != "HoldB"
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Superjump Up
[State -1, Superjump Up]
type = ChangeState
value = 690
triggerall = numhelper(652)= 0
triggerall = command = "holdup"
trigger1 = command = "SuperJumpUp"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 420
trigger2 = movecontact
trigger3 = stateno = 250
trigger3 = movecontact
trigger4 = stateno = 450
trigger4 = movecontact

;---------------------------------------------------------------------------
; Superjump Fwd
[State -1, Superjump Fwd]
type = ChangeState
value = 700
triggerall = numhelper(652)= 0
triggerall = command = "holdfwd"
trigger1 = command = "SuperJumpFwd"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl
;trigger2 = stateno = 420
;trigger2 = movecontact

;---------------------------------------------------------------------------
; Superjump Back
[State -1, Superjump Back]
type = ChangeState
value = 710
triggerall = numhelper(652)= 0
;triggerall = command = "holdback"
trigger1 = command = "SuperJumpBck"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl
;trigger2 = stateno = 420
;trigger2 = movecontact

;---------------------------------------------------------------------------
; Basic Throw
[State -1, Basic Throw]
type = ChangeState
value = 800
triggerall = command = "y" || command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 5
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

[State -1, Back Throw]
type = null;ChangeState
value = 801
triggerall = command = "y" || command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdback"
trigger1 = p2bodydist X < 8
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

;---------------------------------------------------------------------------
; Air Throw
[State -1, Basic Throw]
type = ChangeState
value = 850
triggerall = command = "y" || command = "z"
triggerall = statetype = A
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = pos y <= -50
trigger1 = p2bodydist X < 10
trigger1 = p2movetype != H
trigger1 = p2bodydist Y < 50
trigger1 = p2bodydist Y > -10

;---------------------------------------------------------------------------
; Dive Kick
[State -1, Dive Kick]
type = ChangeState
value = 660
triggerall = statetype = A
triggerall = numhelper(4094) = 0
triggerall = numhelper(667) = 0
;triggerall = command = "holddown"
triggerall = command = "ButSlam"
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = MoveContact
trigger3 = stateno = 610
trigger3 = MoveContact
trigger4 = stateno = 620
trigger4 = MoveContact
trigger5 = stateno = 700  
trigger5 = MoveContact
trigger6 = stateno = 630
trigger6 = MoveContact
trigger7 = stateno = 640
trigger7 = MoveContact
trigger8 = stateno = 4096

;---------------------------------------------------------------------------
; Dive Kick
[State -1, Dive Kick]
type = ChangeState
value = 660
triggerall = statetype = A
triggerall = numhelper(4094) = 1
;triggerall = command = "holddown"
triggerall = command = "russel"
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = MoveContact
trigger3 = stateno = 610
trigger3 = MoveContact
trigger4 = stateno = 620
trigger4 = MoveContact
trigger5 = stateno = 700  
trigger5 = MoveContact
trigger6 = stateno = 630
trigger6 = MoveContact
trigger7 = stateno = 640
trigger7 = MoveContact


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = AnimTime >= 3

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = var(59) = 1
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact

;---------------------------------------------------------------------------
;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 230
trigger3 = MoveContact
trigger4 = stateno = 400
trigger4 = MoveContact
trigger5 = stateno = 430
trigger5 = MoveContact

;---------------------------------------------------------------------------
;Stand Hard Punch
[State -1, Stand Hard Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 210
trigger2 = MoveContact
trigger3 = stateno = 240
trigger3 = MoveContact
trigger4 = stateno = 200
trigger4 = MoveContact
trigger5 = stateno = 230
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 220
triggerall = command != "holddown"
triggerall = var(59) = 1
triggerall = statetype = S
;trigger1 = ctrl
trigger1 = command = "x"
trigger1 = stateno = 210
trigger1 = MoveContact
trigger2 = command = "y"
trigger2 = stateno = 210
trigger2 = MoveContact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = MoveContact
trigger3 = stateno = 400
trigger3 = MoveContact

;---------------------------------------------------------------------------
;Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = MoveContact
trigger3 = stateno = 210
trigger3 = MoveContact
trigger4 = stateno = 200
trigger4 = MoveContact
trigger5 = stateno = 400
trigger5 = MoveContact
trigger6 = stateno = 410
trigger6 = MoveContact
trigger7 = stateno = 430
trigger7 = MoveContact

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 240
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = var(59) = 1
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = MoveContact


;---------------------------------------------------------------------------
;Standing Hard Kick
[State -1, Standing Hard Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact
trigger3 = stateno = 210
trigger3 = MoveContact
trigger4 = stateno = 230
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 400
trigger6 = MoveContact
trigger7 = stateno = 410
trigger7 = MoveContact
trigger8 = stateno = 430
trigger8 = MoveContact
trigger9 = stateno = 440
trigger9 = MoveContact
trigger10 = numhelper(4094) = 1
trigger10 = stateno = 420
trigger10 = MoveContact
trigger11 = stateno = 220
;trigger11 = MoveContact

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 250
triggerall = command != "holddown"
triggerall = var(59) = 1
triggerall = statetype = S
;triggerall = ctrl
trigger1 = command = "a"
trigger1 = stateno = 240
trigger1 = MoveContact
trigger2 = command = "b"
trigger2 = stateno = 240
trigger2 = MoveContact

[State -1, Punch Launcher Followup]
type = ChangeState
value = 690
triggerall = command = "x"
triggerall = statetype = S
triggerall = var(59) = 1
;trigger1 = ctrl
trigger1 = stateno = 250
trigger1 = time >= 2
trigger1 = MoveHit

[State -1, Punch Launcher Followup]
type = ChangeState
value = 690
triggerall = command = "a"
triggerall = statetype = S
triggerall = var(59) = 1
;trigger1 = ctrl
trigger1 = stateno = 250
trigger1 = MoveHit

[State -1, Punch Launcher Followup]
type = ChangeState
value = 690
triggerall = command = "y"
triggerall = statetype = S
triggerall = var(59) = 1
;trigger1 = ctrl
trigger1 = stateno = 250
trigger1 = time >= 2
trigger1 = MoveHit

[State -1, Punch Launcher Followup]
type = ChangeState
value = 690
triggerall = command = "b"
triggerall = statetype = S
triggerall = var(59) = 1
;trigger1 = ctrl
trigger1 = stateno = 250
trigger1 = MoveHit

[State -1, Kick Launcher Followup]
type = ChangeState
value = 670
triggerall = command = "holdup"
trigger1 = MoveHit
trigger1 = stateno = 250


;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 240
trigger2 = MoveContact

;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command = "holddown"
triggerall = command = "y"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = MoveContact
trigger3 = stateno = 430
trigger3 = MoveContact
trigger4 = stateno = 200
trigger4 = MoveContact
trigger5 = stateno = 230
trigger5 = MoveContact

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 410
triggerall = command = "x"
;triggerall = command = "holddown"
triggerall = statetype = C
triggerall = var(59) = 1
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = MoveContact

;---------------------------------------------------------------------------
;Crouching Hard Punch
[State -1, Crouching Hard Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 410
trigger2 = MoveContact
trigger3 = stateno = 400
trigger3 = MoveContact
trigger4 = stateno = 430
trigger4 = MoveContact
trigger5 = stateno = 440
trigger5 = MoveContact
trigger6 = stateno = 200
trigger6 = MoveContact
trigger7 = stateno = 210
trigger7 = MoveContact
trigger8 = stateno = 230
trigger8 = MoveContact
trigger9 = stateno = 240
trigger9 = MoveContact
trigger10 = stateno = 220
trigger10 = Time >= 30

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 420
triggerall = command = "x"
;triggerall = command = "holddown"
triggerall = statetype = C
triggerall = var(59) = 1
trigger1 = ctrl
trigger2 = stateno = 410
trigger2 = MoveContact

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 420
triggerall = command = "y"
;triggerall = command = "holddown"
triggerall = statetype = C
triggerall = var(59) = 1
trigger1 = ctrl
trigger2 = stateno = 410
trigger2 = MoveContact

[State -1, Launcher Followup]
type = ChangeState
value = 670
triggerall = command = "holdup"
trigger1 = MoveHit
trigger1 = stateno = 420


;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 430
trigger2 = MoveContact
trigger2 = AnimElem = 3
trigger3 = stateno = 400
trigger3 = MoveContact
trigger4 = stateno = 200
trigger4 = MoveContact

;---------------------------------------------------------------------------
;Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 430
trigger2 = MoveContact
trigger3 = stateno = 400
trigger3 = MoveContact
trigger4 = stateno = 410
trigger4 = MoveContact
trigger5 = stateno = 200
trigger5 = MoveContact
trigger6 = stateno = 210
trigger6 = MoveContact
trigger7 = stateno = 230
trigger7 = MoveContact

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 440
triggerall = command = "a"
;triggerall = command = "holddown"
triggerall = statetype = C
triggerall = var(59) = 1
trigger1 = ctrl
trigger2 = stateno = 430
trigger2 = MoveContact

;---------------------------------------------------------------------------
;Crouching Hard Kick
[State -1, Crouching Hard Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = MoveContact
trigger3 = stateno = 410
trigger3 = MoveContact
trigger4 = stateno = 420
trigger4 = MoveContact
trigger5 = stateno = 430
trigger5 = MoveContact
trigger6 = stateno = 200
trigger6 = MoveContact
trigger7 = stateno = 210
trigger7 = MoveContact
trigger8 = stateno = 220
trigger8 = MoveContact
trigger9 = stateno = 230
trigger9 = MoveContact
trigger10 = stateno = 440
trigger10 = MoveContact
trigger11 = stateno = 240
trigger11 = MoveContact

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 450
triggerall = command = "a"
;triggerall = command = "holddown"
triggerall = statetype = C
triggerall = var(59) = 1
trigger1 = ctrl
trigger2 = stateno = 440
trigger2 = MoveContact

;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 450
triggerall = command = "b"
;triggerall = command = "holddown"
triggerall = statetype = C
triggerall = var(59) = 1
trigger1 = ctrl
trigger2 = stateno = 440
trigger2 = MoveContact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(15) = 0
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = AnimElem = 1
trigger3 = stateno = 2446
trigger3 = MoveContact
trigger4 = stateno = 660
trigger4 = MoveContact


;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(15) = 0
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = MoveContact
trigger3 = stateno = 630
trigger3 = MoveContact
trigger4 = stateno = 660
trigger4 = MoveContact

[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(15) = 0
triggerall = var(59) = 1
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = MoveContact


;---------------------------------------------------------------------------
;Jump Hard Punch
[State -1, Jump Hard Punch]
type = ChangeState
value = 620
triggerall = var(15) = 0
triggerall = command = "z"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = MoveContact
trigger3 = stateno = 610
trigger3 = MoveContact
trigger4 = stateno = 630
trigger4 = MoveContact
trigger5 = stateno = 640
trigger5 = MoveContact
trigger6 = stateno = 700
trigger6 = MoveContact
trigger7 = stateno = 660
trigger7 = movecontact

[State -1, Jump Medium Punch]
type = ChangeState
value = 620
triggerall = var(15) = 0
triggerall = var(59) = 1
triggerall = command = "x"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610
trigger2 = MoveContact

[State -1, Jump Medium Punch]
type = ChangeState
value = 620
triggerall = var(15) = 0
triggerall = var(59) = 1
triggerall = command = "y"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610
trigger2 = MoveContact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(15) = 0
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = MoveHit
trigger3 = stateno = 660
trigger3 = MoveContact


;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = var(15) = 0
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610
trigger2 = MoveContact
trigger3 = stateno = 630
trigger3 = MoveContact
trigger4 = stateno = 600
trigger4 = MoveContact
trigger5 = stateno = 660
trigger5 = MoveContact

[State -1, Jump Medium Punch]
type = ChangeState
value = 640
triggerall = var(15) = 0
triggerall = var(59) = 1
triggerall = command = "a"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 630
trigger2 = MoveContact

;---------------------------------------------------------------------------
;Jump Hard Kick
[State -1, Jump Hard Kick]
type = ChangeState
value = 650
triggerall = var(15) = 0
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = MoveContact
trigger3 = stateno = 610
trigger3 = MoveContact
trigger4 = stateno = 620
trigger4 = MoveContact
trigger5 = stateno = 630
trigger5 = MoveContact
trigger6 = stateno = 640
trigger6 = movecontact
trigger7 = stateno = 660
trigger7 = MoveContact


[State -1, Jump Medium Punch]
type = ChangeState
value = 650
triggerall = var(15) = 0
triggerall = var(59) = 1
triggerall = command = "a"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 640
trigger2 = MoveContact

[State -1, Jump Medium Punch]
type = ChangeState
value = 650
triggerall = var(15) = 0
triggerall = var(59) = 1
triggerall = command = "b"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 640
trigger2 = MoveContact

[State 9000, 1]
type = Explod
trigger1 = Teamside = 1
triggerall = roundstate = 2
triggerall = Var(59) = 1
trigger1 = numexplod(1003) = 0
ID = 1003
anim = 1220;1020; 998;
pos = 34,232
postype = left
ontop = 1
supermove = 99999
bindtime = -1
removetime = -2
ownpal = 1
scale = 0.5,0.5
sprpriority = 5
ontop = 1

[State 9000, 1]
type = Explod
trigger1 = Teamside = 2
triggerall = roundstate = 2
triggerall = Var(59) = 1
trigger1 = numexplod(1003) = 0
ID = 1003
anim = 1220;1020; 998;
pos = 294,232
postype = left
ontop = 1
supermove = 99999
bindtime = -1
removetime = -2
ownpal = 1
scale = 0.5,0.5
sprpriority = 5
ontop = 1

[State 0, Helper]
type = Helper
trigger1 = roundstate = 1
trigger1 = Var(57) = 1
trigger1 = NumHelper(198) = 0
helpertype = normal ;player
;name =
ID = 198
stateno = 6007
pos = 0,-120
postype = p1    ;p2,front,back,left,right
facing = 1
keyctrl = 0
ownpal = 1
supermove = 9999
;pausemove
size.xscale = .75
size.yscale = .75

[State 9000, 1]
type = Explod
trigger1 = roundstate = 2
trigger1 = Pos y >= 0
trigger1 = P2dist y <= -200
trigger1 = numexplod(188) = 0
ID = 188
anim = F103;1020; 998;
pos = 0,-160
postype = P1
ontop = 1
supermove = 99999
bindtime = -1
removetime = -2
ownpal = 1
scale = 1,1
sprpriority = 5
ontop = 1

[State 620, RemoveExplod]
type = RemoveExplod
trigger1 = Stateno != 4295
ID = 4295
;ignorehitpause = 0
;persistent = 1

[State 620, RemoveExplod]
type = RemoveExplod
trigger1 = Stateno != 1302
ID = 1302
;ignorehitpause = 0
;persistent = 1

[State 620, RemoveExplod]
type = RemoveExplod
trigger1 = Stateno != 1310
ID = 1310
;ignorehitpause = 0
;persistent = 1


[State 8017]
type = Helper
triggerall = NumHelper(5002) = 0
;triggerall = ctrl = 1
triggerall = prevstateno != 195
triggerall = Stateno = 0;Time = 1
triggerall = var(57) = 1
trigger1 = prevstateno <= 199
trigger1 = prevstateno >= 170
trigger2 = numhelper(198) = 1
trigger2 = prevstateno = 5900
id = 5002
helpertype = normal
postype = p1
pos = 352,0
stateno = 1403
keyctrl = 1
ownpal = 1
;supermovetime = 9999
size.xscale= .2
size.yscale= .1

[State 8017]
type = Helper
triggerall = NumHelper(9998) = 0
trigger1 = stateno = 640;Hitcount >= 10
id = 9998
stateno = 9998
helpertype = normal
postype = p1
pos = 352,0
keyctrl = 0
ownpal = 1
supermovetime = 9999
persistent = 1














































































































































































































































































































































